function [dKdx1,dKdx2,dKdy1,dKdy2,dKdz1,dKdz2] = dtruss3dKe(XYZ,A,E,Computation)
// [dKdx1,dKdx2,dKdy1,dKdy2,dKdz1,dKdz2] = dtruss3dKe(XYZ,A,E)
// Calcul de la matrice elementaire des derivees partielles pour un  
// element barre a deux noeuds (x1,y1,z1) (x2,y2,z2)
// A : section de l'element
// E : module d'elasticite 
// XYZ: cordonnees des noeuds  XYZ = [x1,y1,z1; x2,y2,z2]
// A. Seghir, 06/08/04
// Y. Collette 01/10/07

[L,cx,cy,cz] = EltLen(XYZ);  

x1 = XYZ(1,1);
x2 = XYZ(2,1);
y1 = XYZ(1,2);
y2 = XYZ(2,2);
z1 = XYZ(1,3);
z2 = XYZ(2,3);

dKdx1 = [];
dKdx2 = [];
dKdy1 = [];
dKdy2 = [];
dKdz1 = [];
dKdz2 = [];

// Original matrix

ke = (A*E/L) * [ cx^2,   cx*cy,  cx*cz, -cx^2,  -cx*cy, -cx*cz; ...
                 cx*cy,  cy^2,   cy*cz, -cx*cy, -cy^2,  -cy*cz; ...
                 cx*cz,  cy*cz,  cz^2,  -cx*cz, -cy*cz, -cz^2; ...
                -cx^2,  -cx*cy, -cx*cz,  cx^2,   cx*cy,  cx*cz; ...
                -cx*cy, -cy^2,  -cy*cz,  cx*cy,  cy^2,   cy*cz; ...
                -cx*cz, -cy*cz, -cz^2,   cx*cz,  cy*cz,  cz^2];

// Maxima commands to generate the stiffness partial derivative matrix
// display2d:false;
// CX(x1,x2,y1,y2,z1,z2):= (x2-x1)/sqrt((x1-x2)^2+(y1-y2)^2+(z1-z2)^2);
// CY(x1,x2,y1,y2,z1,z2):= (y2-y1)/sqrt((x1-x2)^2+(y1-y2)^2+(z1-z2)^2);
// CZ(x1,x2,y1,y2,z1,z2):= (z2-z1)/sqrt((x1-x2)^2+(y1-y2)^2+(z1-z2)^2);

// K(x1,x2,y1,y2,z1,z2):=A*E/sqrt((x1-x2)^2+(y1-y2)^2+(z1-z2)^2)*matrix([ CX(x1,x2,y1,y2,z1,z2)^2,                      CX(x1,x2,y1,y2,z1,z2)*CY(x1,x2,y1,y2,z1,z2),  CX(x1,x2,y1,y2,z1,z2)*CZ(x1,x2,y1,y2,z1,z2), -CX(x1,x2,y1,y2,z1,z2)^2,                     -CX(x1,x2,y1,y2,z1,z2)*CY(x1,x2,y1,y2,z1,z2), -CX(x1,x2,y1,y2,z1,z2)*CZ(x1,x2,y1,y2,z1,z2)], ...
//                                                                      [ CX(x1,x2,y1,y2,z1,z2)*CY(x1,x2,y1,y2,z1,z2),  CY(x1,x2,y1,y2,z1,z2)^2,                      CY(x1,x2,y1,y2,z1,z2)*CZ(x1,x2,y1,y2,z1,z2), -CX(x1,x2,y1,y2,z1,z2)*CY(x1,x2,y1,y2,z1,z2), -CY(x1,x2,y1,y2,z1,z2)^2,                     -CY(x1,x2,y1,y2,z1,z2)*CZ(x1,x2,y1,y2,z1,z2)], ...
//                                                                      [ CX(x1,x2,y1,y2,z1,z2)*CZ(x1,x2,y1,y2,z1,z2),  CY(x1,x2,y1,y2,z1,z2)*CZ(x1,x2,y1,y2,z1,z2),  CZ(x1,x2,y1,y2,z1,z2)^2,                     -CX(x1,x2,y1,y2,z1,z2)*CZ(x1,x2,y1,y2,z1,z2), -CY(x1,x2,y1,y2,z1,z2)*CZ(x1,x2,y1,y2,z1,z2), -CZ(x1,x2,y1,y2,z1,z2)^2], ...
//                                                                      [-CX(x1,x2,y1,y2,z1,z2)^2,                     -CX(x1,x2,y1,y2,z1,z2)*CY(x1,x2,y1,y2,z1,z2), -CX(x1,x2,y1,y2,z1,z2)*CZ(x1,x2,y1,y2,z1,z2),  CX(x1,x2,y1,y2,z1,z2)^2,                      CX(x1,x2,y1,y2,z1,z2)*CY(x1,x2,y1,y2,z1,z2),  CX(x1,x2,y1,y2,z1,z2)*CZ(x1,x2,y1,y2,z1,z2)], ...
//                                                                      [-CX(x1,x2,y1,y2,z1,z2)*CY(x1,x2,y1,y2,z1,z2), -CY(x1,x2,y1,y2,z1,z2)^2,                     -CY(x1,x2,y1,y2,z1,z2)*CZ(x1,x2,y1,y2,z1,z2),  CX(x1,x2,y1,y2,z1,z2)*CY(x1,x2,y1,y2,z1,z2),  CY(x1,x2,y1,y2,z1,z2)^2,                      CY(x1,x2,y1,y2,z1,z2)*CZ(x1,x2,y1,y2,z1,z2)], ...
//                                                                      [-CX(x1,x2,y1,y2,z1,z2)*CZ(x1,x2,y1,y2,z1,z2), -CY(x1,x2,y1,y2,z1,z2)*CZ(x1,x2,y1,y2,z1,z2), -CZ(x1,x2,y1,y2,z1,z2)^2,                      CX(x1,x2,y1,y2,z1,z2)*CZ(x1,x2,y1,y2,z1,z2),  CY(x1,x2,y1,y2,z1,z2)*CZ(x1,x2,y1,y2,z1,z2),  CZ(x1,x2,y1,y2,z1,z2)^2]);

//
// Result:
// * dK/dx1
// dKdx1:diff(K(x1,x2,y1,y2,z1,z2),x1);
// dKdx1:factor(dKdx1);

dKdx1 = [-(x2-x1)*(2*z2^2-4*z1*z2+2*z1^2+2*y2^2-4*y1*y2+2*y1^2-x2^2+2*x1*x2-x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(y2-y1)*(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2-2*x2^2+4*x1*x2-2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(z2-z1)*(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2-2*x2^2+4*x1*x2-2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), (x2-x1)*(2*z2^2-4*z1*z2+2*z1^2+2*y2^2-4*y1*y2+2*y1^2-x2^2+2*x1*x2-x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), (y2-y1)*(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2-2*x2^2+4*x1*x2-2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), (z2-z1)*(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2-2*x2^2+4*x1*x2-2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2); ...
         -(y2-y1)*(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2-2*x2^2+4*x1*x2-2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), 3*(x2-x1)*(y2-y1)^2*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), 3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2),(y2-y1)*(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2-2*x2^2+4*x1*x2-2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -3*(x2-x1)*(y2-y1)^2*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2); ...
         -(z2-z1)*(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2-2*x2^2+4*x1*x2-2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), 3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), 3*(x2-x1)*(z2-z1)^2*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2),(z2-z1)*(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2-2*x2^2+4*x1*x2-2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2),-3*(x2-x1)*(z2-z1)^2*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2); ...
          (x2-x1)*(2*z2^2-4*z1*z2+2*z1^2+2*y2^2-4*y1*y2+2*y1^2-x2^2+2*x1*x2-x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), (y2-y1)*(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2-2*x2^2+4*x1*x2-2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), (z2-z1)*(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2-2*x2^2+4*x1*x2-2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(x2-x1)*(2*z2^2-4*z1*z2+2*z1^2+2*y2^2-4*y1*y2+2*y1^2-x2^2+2*x1*x2-x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(y2-y1)*(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2-2*x2^2+4*x1*x2-2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(z2-z1)*(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2-2*x2^2+4*x1*x2-2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2); ...
          (y2-y1)*(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2-2*x2^2+4*x1*x2-2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -3*(x2-x1)*(y2-y1)^2*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(y2-y1)*(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2-2*x2^2+4*x1*x2-2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), 3*(x2-x1)*(y2-y1)^2*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), 3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2); ...
          (z2-z1)*(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2-2*x2^2+4*x1*x2-2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -3*(x2-x1)*(z2-z1)^2*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(z2-z1)*(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2-2*x2^2+4*x1*x2-2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), 3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), 3*(x2-x1)*(z2-z1)^2*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2)];
           
// * dK/dx2
// dKdx2:diff(K(x1,x2,y1,y2,z1,z2),x2);
// dKdx2:factor(dKdx2);

dKdx2 = [(x2-x1)*(2*z2^2-4*z1*z2+2*z1^2+2*y2^2-4*y1*y2+2*y1^2-x2^2+2*x1*x2-x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), (y2-y1)*(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2-2*x2^2+4*x1*x2-2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), (z2-z1)*(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2-2*x2^2+4*x1*x2-2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(x2-x1)*(2*z2^2-4*z1*z2+2*z1^2+2*y2^2-4*y1*y2+2*y1^2-x2^2+2*x1*x2-x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(y2-y1)*(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2-2*x2^2+4*x1*x2-2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(z2-z1)*(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2-2*x2^2+4*x1*x2-2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2); ...
         (y2-y1)*(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2-2*x2^2+4*x1*x2-2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -3*(x2-x1)*(y2-y1)^2*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(y2-y1)*(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2-2*x2^2+4*x1*x2-2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), 3*(x2-x1)*(y2-y1)^2*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), 3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2); ...
         (z2-z1)*(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2-2*x2^2+4*x1*x2-2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -3*(x2-x1)*(z2-z1)^2*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(z2-z1)*(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2-2*x2^2+4*x1*x2-2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), 3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), 3*(x2-x1)*(z2-z1)^2*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2); ...
        -(x2-x1)*(2*z2^2-4*z1*z2+2*z1^2+2*y2^2-4*y1*y2+2*y1^2-x2^2+2*x1*x2-x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(y2-y1)*(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2-2*x2^2+4*x1*x2-2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(z2-z1)*(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2-2*x2^2+4*x1*x2-2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), (x2-x1)*(2*z2^2-4*z1*z2+2*z1^2+2*y2^2-4*y1*y2+2*y1^2-x2^2+2*x1*x2-x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), (y2-y1)*(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2-2*x2^2+4*x1*x2-2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), (z2-z1)*(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2-2*x2^2+4*x1*x2-2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2); ...
        -(y2-y1)*(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2-2*x2^2+4*x1*x2-2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), 3*(x2-x1)*(y2-y1)^2*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), 3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), (y2-y1)*(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2-2*x2^2+4*x1*x2-2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -3*(x2-x1)*(y2-y1)^2*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2); ...
        -(z2-z1)*(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2-2*x2^2+4*x1*x2-2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), 3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), 3*(x2-x1)*(z2-z1)^2*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), (z2-z1)*(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2-2*x2^2+4*x1*x2-2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -3*(x2-x1)*(z2-z1)^2*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2)];
                                       
// * dK/dy1
// dKdy1:diff(K(x1,x2,y1,y2,z1,z2),y1);
// dKdy1:factor(dKdy1);

dKdy1 = [3*(x2-x1)^2*(y2-y1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(x2-x1)*(z2^2-2*z1*z2+z1^2-2*y2^2+4*y1*y2-2*y1^2+x2^2-2*x1*x2+x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), 3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -3*(x2-x1)^2*(y2-y1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2),(x2-x1)*(z2^2-2*z1*z2+z1^2-2*y2^2+4*y1*y2-2*y1^2+x2^2-2*x1*x2+x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2); ...
          -(x2-x1)*(z2^2-2*z1*z2+z1^2-2*y2^2+4*y1*y2-2*y1^2+x2^2-2*x1*x2+x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(y2-y1)*(2*z2^2-4*z1*z2+2*z1^2-y2^2+2*y1*y2-y1^2+2*x2^2-4*x1*x2+2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(z2-z1)*(z2^2-2*z1*z2+z1^2-2*y2^2+4*y1*y2-2*y1^2+x2^2-2*x1*x2+x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), (x2-x1)*(z2^2-2*z1*z2+z1^2-2*y2^2+4*y1*y2-2*y1^2+x2^2-2*x1*x2+x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2),(y2-y1)*(2*z2^2-4*z1*z2+2*z1^2-y2^2+2*y1*y2-y1^2+2*x2^2-4*x1*x2+2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), (z2-z1)*(z2^2-2*z1*z2+z1^2-2*y2^2+4*y1*y2-2*y1^2+x2^2-2*x1*x2+x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2); ...
         3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(z2-z1)*(z2^2-2*z1*z2+z1^2-2*y2^2+4*y1*y2-2*y1^2+x2^2-2*x1*x2+x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), 3*(y2-y1)*(z2-z1)^2*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), (z2-z1)*(z2^2-2*z1*z2+z1^2-2*y2^2+4*y1*y2-2*y1^2+x2^2-2*x1*x2+x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -3*(y2-y1)*(z2-z1)^2*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2); ...
        -3*(x2-x1)^2*(y2-y1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), (x2-x1)*(z2^2-2*z1*z2+z1^2-2*y2^2+4*y1*y2-2*y1^2+x2^2-2*x1*x2+x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2),  3*(x2-x1)^2*(y2-y1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(x2-x1)*(z2^2-2*z1*z2+z1^2-2*y2^2+4*y1*y2-2*y1^2+x2^2-2*x1*x2+x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), 3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2); ...
           (x2-x1)*(z2^2-2*z1*z2+z1^2-2*y2^2+4*y1*y2-2*y1^2+x2^2-2*x1*x2+x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), (y2-y1)*(2*z2^2-4*z1*z2+2*z1^2-y2^2+2*y1*y2-y1^2+2*x2^2-4*x1*x2+2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), (z2-z1)*(z2^2-2*z1*z2+z1^2-2*y2^2+4*y1*y2-2*y1^2+x2^2-2*x1*x2+x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(x2-x1)*(z2^2-2*z1*z2+z1^2-2*y2^2+4*y1*y2-2*y1^2+x2^2-2*x1*x2+x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(y2-y1)*(2*z2^2-4*z1*z2+2*z1^2-y2^2+2*y1*y2-y1^2+2*x2^2-4*x1*x2+2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(z2-z1)*(z2^2-2*z1*z2+z1^2-2*y2^2+4*y1*y2-2*y1^2+x2^2-2*x1*x2+x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2); ...
        -3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), (z2-z1)*(z2^2-2*z1*z2+z1^2-2*y2^2+4*y1*y2-2*y1^2+x2^2-2*x1*x2+x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -3*(y2-y1)*(z2-z1)^2*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), 3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(z2-z1)*(z2^2-2*z1*z2+z1^2-2*y2^2+4*y1*y2-2*y1^2+x2^2-2*x1*x2+x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), 3*(y2-y1)*(z2-z1)^2*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2)];
                                       
// * dK/dy2
// dKdy2:diff(K(x1,x2,y1,y2,z1,z2),y2);
// dKdy2:factor(dKdy2);

dKdy2 = [-3*(x2-x1)^2*(y2-y1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), (x2-x1)*(z2^2-2*z1*z2+z1^2-2*y2^2+4*y1*y2-2*y1^2+x2^2-2*x1*x2+x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), 3*(x2-x1)^2*(y2-y1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(x2-x1)*(z2^2-2*z1*z2+z1^2-2*y2^2+4*y1*y2-2*y1^2+x2^2-2*x1*x2+x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), 3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2); ...
            (x2-x1)*(z2^2-2*z1*z2+z1^2-2*y2^2+4*y1*y2-2*y1^2+x2^2-2*x1*x2+x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), (y2-y1)*(2*z2^2-4*z1*z2+2*z1^2-y2^2+2*y1*y2-y1^2+2*x2^2-4*x1*x2+2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), (z2-z1)*(z2^2-2*z1*z2+z1^2-2*y2^2+4*y1*y2-2*y1^2+x2^2-2*x1*x2+x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(x2-x1)*(z2^2-2*z1*z2+z1^2-2*y2^2+4*y1*y2-2*y1^2+x2^2-2*x1*x2+x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(y2-y1)*(2*z2^2-4*z1*z2+2*z1^2-y2^2+2*y1*y2-y1^2+2*x2^2-4*x1*x2+2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(z2-z1)*(z2^2-2*z1*z2+z1^2-2*y2^2+4*y1*y2-2*y1^2+x2^2-2*x1*x2+x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2); ...
         -3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), (z2-z1)*(z2^2-2*z1*z2+z1^2-2*y2^2+4*y1*y2-2*y1^2+x2^2-2*x1*x2+x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -3*(y2-y1)*(z2-z1)^2*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), 3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(z2-z1)*(z2^2-2*z1*z2+z1^2-2*y2^2+4*y1*y2-2*y1^2+x2^2-2*x1*x2+x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), 3*(y2-y1)*(z2-z1)^2*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2); ...
          3*(x2-x1)^2*(y2-y1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(x2-x1)*(z2^2-2*z1*z2+z1^2-2*y2^2+4*y1*y2-2*y1^2+x2^2-2*x1*x2+x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), 3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -3*(x2-x1)^2*(y2-y1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), (x2-x1)*(z2^2-2*z1*z2+z1^2-2*y2^2+4*y1*y2-2*y1^2+x2^2-2*x1*x2+x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2); ...
           -(x2-x1)*(z2^2-2*z1*z2+z1^2-2*y2^2+4*y1*y2-2*y1^2+x2^2-2*x1*x2+x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(y2-y1)*(2*z2^2-4*z1*z2+2*z1^2-y2^2+2*y1*y2-y1^2+2*x2^2-4*x1*x2+2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(z2-z1)*(z2^2-2*z1*z2+z1^2-2*y2^2+4*y1*y2-2*y1^2+x2^2-2*x1*x2+x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), (x2-x1)*(z2^2-2*z1*z2+z1^2-2*y2^2+4*y1*y2-2*y1^2+x2^2-2*x1*x2+x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), (y2-y1)*(2*z2^2-4*z1*z2+2*z1^2-y2^2+2*y1*y2-y1^2+2*x2^2-4*x1*x2+2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2),(z2-z1)*(z2^2-2*z1*z2+z1^2-2*y2^2+4*y1*y2-2*y1^2+x2^2-2*x1*x2+x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2); ...
          3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(z2-z1)*(z2^2-2*z1*z2+z1^2-2*y2^2+4*y1*y2-2*y1^2+x2^2-2*x1*x2+x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), 3*(y2-y1)*(z2-z1)^2*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), (z2-z1)*(z2^2-2*z1*z2+z1^2-2*y2^2+4*y1*y2-2*y1^2+x2^2-2*x1*x2+x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -3*(y2-y1)*(z2-z1)^2*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2)];
                                        
// * dK/dz1
// dKdz1:diff(K(x1,x2,y1,y2,z1,z2),z1);
// dKdz1:factor(dKdz1);

dKdz1 = [3*(x2-x1)^2*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), 3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), (x2-x1)*(2*z2^2-4*z1*z2+2*z1^2-y2^2+2*y1*y2-y1^2-x2^2+2*x1*x2-x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -3*(x2-x1)^2*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(x2-x1)*(2*z2^2-4*z1*z2+2*z1^2-y2^2+2*y1*y2-y1^2-x2^2+2*x1*x2-x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2); ...
         3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), 3*(y2-y1)^2*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), (y2-y1)*(2*z2^2-4*z1*z2+2*z1^2-y2^2+2*y1*y2-y1^2-x2^2+2*x1*x2-x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -3*(y2-y1)^2*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(y2-y1)*(2*z2^2-4*z1*z2+2*z1^2-y2^2+2*y1*y2-y1^2-x2^2+2*x1*x2-x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2); ...
           (x2-x1)*(2*z2^2-4*z1*z2+2*z1^2-y2^2+2*y1*y2-y1^2-x2^2+2*x1*x2-x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), (y2-y1)*(2*z2^2-4*z1*z2+2*z1^2-y2^2+2*y1*y2-y1^2-x2^2+2*x1*x2-x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), (z2-z1)*(z2^2-2*z1*z2+z1^2-2*y2^2+4*y1*y2-2*y1^2-2*x2^2+4*x1*x2-2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(x2-x1)*(2*z2^2-4*z1*z2+2*z1^2-y2^2+2*y1*y2-y1^2-x2^2+2*x1*x2-x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(y2-y1)*(2*z2^2-4*z1*z2+2*z1^2-y2^2+2*y1*y2-y1^2-x2^2+2*x1*x2-x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(z2-z1)*(z2^2-2*z1*z2+z1^2-2*y2^2+4*y1*y2-2*y1^2-2*x2^2+4*x1*x2-2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2); ...
        -3*(x2-x1)^2*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(x2-x1)*(2*z2^2-4*z1*z2+2*z1^2-y2^2+2*y1*y2-y1^2-x2^2+2*x1*x2-x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), 3*(x2-x1)^2*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), 3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), (x2-x1)*(2*z2^2-4*z1*z2+2*z1^2-y2^2+2*y1*y2-y1^2-x2^2+2*x1*x2-x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2); ...
        -3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -3*(y2-y1)^2*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(y2-y1)*(2*z2^2-4*z1*z2+2*z1^2-y2^2+2*y1*y2-y1^2-x2^2+2*x1*x2-x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), 3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), 3*(y2-y1)^2*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), (y2-y1)*(2*z2^2-4*z1*z2+2*z1^2-y2^2+2*y1*y2-y1^2-x2^2+2*x1*x2-x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2); ...
          -(x2-x1)*(2*z2^2-4*z1*z2+2*z1^2-y2^2+2*y1*y2-y1^2-x2^2+2*x1*x2-x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(y2-y1)*(2*z2^2-4*z1*z2+2*z1^2-y2^2+2*y1*y2-y1^2-x2^2+2*x1*x2-x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(z2-z1)*(z2^2-2*z1*z2+z1^2-2*y2^2+4*y1*y2-2*y1^2-2*x2^2+4*x1*x2-2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), (x2-x1)*(2*z2^2-4*z1*z2+2*z1^2-y2^2+2*y1*y2-y1^2-x2^2+2*x1*x2-x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), (y2-y1)*(2*z2^2-4*z1*z2+2*z1^2-y2^2+2*y1*y2-y1^2-x2^2+2*x1*x2-x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), (z2-z1)*(z2^2-2*z1*z2+z1^2-2*y2^2+4*y1*y2-2*y1^2-2*x2^2+4*x1*x2-2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2)];
                 
// * dK/dz2
// dKdz2:diff(K(x1,x2,y1,y2,z1,z2),z2);
// dKdz2:factor(dKdz2);

dKdz2 = [-3*(x2-x1)^2*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(x2-x1)*(2*z2^2-4*z1*z2+2*z1^2-y2^2+2*y1*y2-y1^2-x2^2+2*x1*x2-x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), 3*(x2-x1)^2*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), 3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), (x2-x1)*(2*z2^2-4*z1*z2+2*z1^2-y2^2+2*y1*y2-y1^2-x2^2+2*x1*x2-x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2); ...
         -3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -3*(y2-y1)^2*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(y2-y1)*(2*z2^2-4*z1*z2+2*z1^2-y2^2+2*y1*y2-y1^2-x2^2+2*x1*x2-x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), 3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), 3*(y2-y1)^2*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), (y2-y1)*(2*z2^2-4*z1*z2+2*z1^2-y2^2+2*y1*y2-y1^2-x2^2+2*x1*x2-x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2); ...
           -(x2-x1)*(2*z2^2-4*z1*z2+2*z1^2-y2^2+2*y1*y2-y1^2-x2^2+2*x1*x2-x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(y2-y1)*(2*z2^2-4*z1*z2+2*z1^2-y2^2+2*y1*y2-y1^2-x2^2+2*x1*x2-x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(z2-z1)*(z2^2-2*z1*z2+z1^2-2*y2^2+4*y1*y2-2*y1^2-2*x2^2+4*x1*x2-2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), (x2-x1)*(2*z2^2-4*z1*z2+2*z1^2-y2^2+2*y1*y2-y1^2-x2^2+2*x1*x2-x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), (y2-y1)*(2*z2^2-4*z1*z2+2*z1^2-y2^2+2*y1*y2-y1^2-x2^2+2*x1*x2-x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), (z2-z1)*(z2^2-2*z1*z2+z1^2-2*y2^2+4*y1*y2-2*y1^2-2*x2^2+4*x1*x2-2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2); ...
          3*(x2-x1)^2*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), 3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), (x2-x1)*(2*z2^2-4*z1*z2+2*z1^2-y2^2+2*y1*y2-y1^2-x2^2+2*x1*x2-x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -3*(x2-x1)^2*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(x2-x1)*(2*z2^2-4*z1*z2+2*z1^2-y2^2+2*y1*y2-y1^2-x2^2+2*x1*x2-x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2); ...
          3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), 3*(y2-y1)^2*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), (y2-y1)*(2*z2^2-4*z1*z2+2*z1^2-y2^2+2*y1*y2-y1^2-x2^2+2*x1*x2-x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -3*(x2-x1)*(y2-y1)*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -3*(y2-y1)^2*(z2-z1)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(y2-y1)*(2*z2^2-4*z1*z2+2*z1^2-y2^2+2*y1*y2-y1^2-x2^2+2*x1*x2-x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2); ...
            (x2-x1)*(2*z2^2-4*z1*z2+2*z1^2-y2^2+2*y1*y2-y1^2-x2^2+2*x1*x2-x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), (y2-y1)*(2*z2^2-4*z1*z2+2*z1^2-y2^2+2*y1*y2-y1^2-x2^2+2*x1*x2-x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), (z2-z1)*(z2^2-2*z1*z2+z1^2-2*y2^2+4*y1*y2-2*y1^2-2*x2^2+4*x1*x2-2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(x2-x1)*(2*z2^2-4*z1*z2+2*z1^2-y2^2+2*y1*y2-y1^2-x2^2+2*x1*x2-x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(y2-y1)*(2*z2^2-4*z1*z2+2*z1^2-y2^2+2*y1*y2-y1^2-x2^2+2*x1*x2-x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2), -(z2-z1)*(z2^2-2*z1*z2+z1^2-2*y2^2+4*y1*y2-2*y1^2-2*x2^2+4*x1*x2-2*x1^2)*A*E/(z2^2-2*z1*z2+z1^2+y2^2-2*y1*y2+y1^2+x2^2-2*x1*x2+x1^2)^(5/2)];
endfunction
